@@ -6,9 +6,8 @@
 # $1: python executable
 # $2: python test
 # $3: qrc file
-# $5: pyside-rcc path
 
 export PYTHONPATH=$PYTHONPATH:`pwd`
-$5/pyside-rcc -o `basename $3 .qrc`_rc.py $3
+pyside-rcc -o `basename $3 .qrc`_rc.py $3
 cd $4
 $1 $2
